@@ -1,8 +1,13 @@
 from energytt_platform.bus import message_registry
 
-from .users import UserOnboarded
-from .tech import TechnologyUpdate, TechnologyRemoved
-from .auth import (
+from .users import (
+    UserOnboarded,
+)
+from .tech import (
+    TechnologyUpdate,
+    TechnologyRemoved,
+)
+from .delegates import (
     MeteringPointOwnerUpdate,
     MeteringPointDelegateGranted,
     MeteringPointDelegateRevoked,
@@ -26,7 +31,7 @@ message_registry.add(
     # Users
     UserOnboarded,
 
-    # Authentication
+    # Delegates
     MeteringPointOwnerUpdate,
     MeteringPointDelegateGranted,
     MeteringPointDelegateRevoked,
